This is the mail archive of the binutils-cvs@sourceware.org mailing list for the binutils project.


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]
Other format: [Raw text]

[binutils-gdb] Fix typos in comments in _bfd_elf_merge_symbol


https://sourceware.org/git/gitweb.cgi?p=binutils-gdb.git;h=ae7683d2389973fbd368ee1ac77413a3cd1e4a7a

commit ae7683d2389973fbd368ee1ac77413a3cd1e4a7a
Author: H.J. Lu <hjl.tools@gmail.com>
Date:   Thu Oct 15 11:01:39 2015 -0700

    Fix typos in comments in _bfd_elf_merge_symbol
    
    	* elflink.c (_bfd_elf_merge_symbol): Fix typos in comments

Diff:
---
 bfd/ChangeLog | 4 ++++
 bfd/elflink.c | 4 ++--
 2 files changed, 6 insertions(+), 2 deletions(-)

diff --git a/bfd/ChangeLog b/bfd/ChangeLog
index 77e33e4..8400cf6 100644
--- a/bfd/ChangeLog
+++ b/bfd/ChangeLog
@@ -1,3 +1,7 @@
+2015-10-15  H.J. Lu  <hongjiu.lu@intel.com>
+
+	* elflink.c (_bfd_elf_merge_symbol): Fix typos in comments
+
 2015-10-15  Alan Modra  <amodra@gmail.com>
 
 	* elf32-v850.c (v850_elf_copy_private_bfd_data): Remove assertion
diff --git a/bfd/elflink.c b/bfd/elflink.c
index 839cebb..73fe469 100644
--- a/bfd/elflink.c
+++ b/bfd/elflink.c
@@ -1010,9 +1010,9 @@ _bfd_elf_merge_symbol (bfd *abfd,
 	*matched = TRUE;
       else
 	{
 	  /* OLD_HIDDEN is true if the existing symbol is only visibile
 	     to the symbol with the same symbol version.  NEW_HIDDEN is
-	     true if the new symbol is only visibile to the symbol with
+	     true if the new symbol is only visible to the symbol with
 	     the same symbol version.  */
 	  bfd_boolean old_hidden = h->versioned == versioned_hidden;
 	  bfd_boolean new_hidden = hi->versioned == versioned_hidden;
@@ -1010,9 +1010,9 @@ _bfd_elf_merge_symbol (bfd *abfd,
       else
 	{
-	  /* OLD_HIDDEN is true if the existing symbol is only visibile
+	  /* OLD_HIDDEN is true if the existing symbol is only visible
 	     to the symbol with the same symbol version.  NEW_HIDDEN is


Index Nav: [Date Index] [Subject Index] [Author Index] [Thread Index]
Message Nav: [Date Prev] [Date Next] [Thread Prev] [Thread Next]